#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage			 : http://www.ne.jp/asahi/linux/timecop/
# source location    : http://www.ne.jp/asahi/linux/timecop/software/bubblemon-dockapp-1.46.tar.gz
# last revised       : 15.9.2009
# dep                : 

softname='bubblemon-dockapp'
softversion='1.46'
packageversion='1fb'

arch='i486'
cpu='i686'

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://www.ne.jp/asahi/linux/timecop/software/bubblemon-dockapp-1.46/$softname-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/bin
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
                 |-----handy-ruler------------------------------------------------------|
bubblemon-dockapp: bubblemon-dockapp (A system CPU and memory load monitor)
bubblemon-dockapp:
bubblemon-dockapp: It displays something that looks like a vial containing water. 
bubblemon-dockapp: The water level indicates how much memory is in use. The color of 
bubblemon-dockapp: the liquid indicates how much swap space is used (watery blue means 
bubblemon-dockapp: none and angry red means all). The system CPU load is indicated by 
bubblemon-dockapp: bubbles floating up through the liquid; lots of bubbles means high 
bubblemon-dockapp: CPU load. If you have unread mail, a message in a bottle falls 
bubblemon-dockapp: into the water.
bubblemon-dockapp: 
bubblemon-dockapp:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# build

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    patch -p1 < ../bubblemon-1.46-gtk.patch

    make
    
    cp bubblemon $dest/usr/bin

# add 'default' files
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      ChangeLog INSTALL README SUPPORTED_SYSTEMS\
      $dest/usr/doc/$softname-$softversion
	cp -a doc/COPYING doc/Xdefaults.sample $dest/usr/doc/$softname-$softversion

# strip executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

# SalixBuild
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion
cp $buildir/bubblemon-1.46-gtk.patch $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "atk,cairo,expat,fontconfig,freetype,glib2,gtk+2,libX11,\
libXau,libXcomposite,libXcursor,libXdamage,libXdmcp,libXext,\
libXfixes,libXi,libXinerama,libXrandr,libXrender,libpng,libxcb,\
pango,pixman,zlib" > $package.dep

# src file
echo http://zenwalk.pinguix.com/user-accounts/bip/divers/salix/xap/wmnd/build-wmnd.sh > $package.src
echo http://zenwalk.pinguix.com/user-accounts/bip/divers/salix/xap/bubblemon/bubblemon-1.46-gtk.patch > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
